@@ -1,6 +1,6 @@
 package Module::Build::Bundle;
 
-# $Id: Bundle.pm 7663 2011-05-06 15:53:06Z jonasbn $
+# $Id: Bundle.pm 7731 2011-06-15 20:14:50Z jonasbn $
 
 use 5.006; #$^V
 use strict;
@@ -14,7 +14,7 @@ use base qw(Module::Build);
 
 use constant EXTENDED_POD_LINK_VERSION => 5.12.0;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 #HACK: we need a writable copy for testing purposes
 our $myPERL_VERSION = $^V; 
@@ -73,7 +73,10 @@ sub ACTION_contents {
     my @path = split /::/, $self->{properties}->{module_name}
         || $self->{properties}->{module_name};
 
-    my $file = $cwd.'/lib/'. (join '/', @path) .'.pm';
+	#HACK: induced from test suite
+	my $dir = $self->notes('temp_wd')?$self->notes('temp_wd'):'lib';
+	
+    my $file = (join '/', ($cwd, $dir, @path)) .'.pm';
     open(FIN, '+<', $file)
         or croak "Unable to open file: $file - $!";
         
@@ -202,7 +205,7 @@ Module::Build::Bundle - subclass for supporting Tasks and Bundles
 
 =head1 VERSION
 
-This documentation describes version 0.06
+This documentation describes version 0.07
 
 =head1 SYNOPSIS
 
@@ -412,13 +415,17 @@ The distribution requires perl version from 5.6.0 and up.
 
 =head1 BUGS AND LIMITATIONS
 
-There are no known bugs or special limitations at this time, but I am sure there
-are plenty of scenarios is distribution packaging the module is not currently
-handling.
+Currently Module::Build::Bundle is not able to handle root based distributions
+meaning distribtions with a single Perl module located in the root directory
+instead of the lib structure.
 
-Currently the module only supports Bundle/Task distributions based on
-Module::Build. The implementation is based on a subclass of Module::Build, which
-can replace Module::Build (See: L</SYNOPSIS>).
+Apart from that there are no known special limitations or bugs at this time,
+but I am certain there are plenty of scenarios is distribution packaging the
+module is not currently handling.
+
+The module only supports Bundle/Task distributions based on L<Module::Build>.
+The implementation is based on a subclass of Module::Build, which can replace
+L<Module::Build> (See: L</SYNOPSIS>).
 
 =head1 SEE ALSO
 
